## gguf-pack

install it via pip/pip3 by:
```
pip install gguf-pack
```

download the pack by:
```
py -m gguf_pack
```
if no py command, use python/python3

### run the pack
- locate the .bat file in the main directory and run it
- this is a developmental clone/pack for code editing purpose